#
# spec file for package python-gmpy2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-gmpy2
Version:        2.1.5
Release:        5.1
Summary:        GMP/MPIR, MPFR, and MPC interface to Python 2.6+ and 3x
License:        LGPL-3.0-only
URL:            https://github.com/aleaxit/gmpy
Source:         https://files.pythonhosted.org/packages/source/g/gmpy2/gmpy2-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/aleaxit/gmpy/pull/422 Update MPFR to 4.2.1 in build scripts & fix test failures on new version
Patch0:         mpfr421.patch
# PATCH-FIX-UPSTREAM file included in https://github.com/aleaxit/gmpy/issues/418#issuecomment-1706721394
Patch1:         gmpy2_cache.c.diff
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gmp-devel
BuildRequires:  mpc-devel
BuildRequires:  mpfr-devel
BuildRequires:  python-rpm-macros

%python_subpackages

%description
gmpy2 is a C-coded Python extension module that supports
multiple-precision arithmetic. In addition to supporting
GMP or MPIR for multiple-precision integer and rational
arithmetic, gmpy2 adds support for the MPFR (correctly
rounded real floating-point arithmetic) and MPC (correctly
rounded complex floating-point arithmetic) libraries.

%prep
%autosetup -p1 -n gmpy2-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%{python_expand export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{$python_sitearch}
pushd test
$python runtests.py
popd
}

%files %{python_files}
%doc README
%license COPYING COPYING.LESSER
%{python_sitearch}/gmpy2
%{python_sitearch}/gmpy2-%{version}*-info

%changelog
* Wed Sep 27 2023 ecsos <ecsos@opensuse.org>
- Fix build error "patch defined multiple times" for Leap.
* Tue Sep 19 2023 Markéta Machová <mmachova@suse.com>
- Add upstream mpfr421.patch and gmpy2_cache.c.diff to fix build
  with mpfr 4.2.1
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Apr  7 2023 Jan Engelhardt <jengelh@inai.de>
- Remove unused build dependency on mpir (gmp was used anyway)
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to gmpy2-2.1.5:
  * Final (?) release of the 2.1.x series. No code changes since 2.1.3.
    Fixes to build Apple Silicon binary builds are the only changes since
  * Latest release with minor bug fixes and support for Python 3.11
* Mon Feb 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.2:
  * Allow GIL release for mpz/xmpz/mpq types only.
  * Improve argument type processing by saving type information to
    decrease the number of type check calls. Especially helpful for mpfr and mpc types.
  * Avoid MPFR bug in mfr_fac_ui (gmpy2.factorial) on platforms where
    long is 32-bits and argument is >= 44787929.
  * Adjust test suite to reflect changes in output in MPFR 4.1.0.
  * Added cmp() and cmp_abs().
  * Improved compatibility with _numbers_ protocol.
  * Initial support for MPFR4
    + Add nrandom()
    + grandom() now calls nrandom twice; may return different values versus MPFR3
    + Add rootn(); same as root() except different sign when taking even root of -0.0
  * Thread-safe contexts are now supported. Properly integrating thread-safe contexts required
    an extensive rewrite of almost all internal functions.
  * MPFR and MPC are now required. It is no longer possible to build a version of gmpy2 that
    only supports the GMP library.
  * The function inverse() now raises an exception if the inverse does not exist.
  * Context methods have been added for MPFR/MPC related functions.
  * A new context option (rational_division) has been added that changes the behavior of
    integer division involving mpz instances to return a rational result instead of a
    floating point result.
  * gmpy2 types are now registered in the numeric tower.
- Remove unzip BuildRequires, as upstream has switched to tarballs.
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
* Sat Aug 26 2017 toddrme2178@gmail.com
- Initial version
